@@ -31,7 +31,6 @@ This module contains configuration classes for Nicotine.
 import configparser
 import os
 import pickle
-import shelve
 import sys
 import time
 
@@ -41,20 +40,12 @@ from os.path import exists
 
 from pynicotine.logfacility import log
 
-if sys.platform == "win32":
-    # Use semidbm for faster shelves on Windows
-
-    def shelve_open_semidbm(filename, flag='c', protocol=None, writeback=False):
-        import semidbm
-        return shelve.Shelf(semidbm.open(filename, flag), protocol, writeback)
-
-    shelve.open = shelve_open_semidbm
-
 
 class RestrictedUnpickler(pickle.Unpickler):
     """
     Don't allow code execution from pickles
     """
+
     def find_class(self, module, name):
         # Forbid all globals
         raise pickle.UnpicklingError("global '%s.%s' is forbidden" %
@@ -66,11 +57,11 @@ class Config:
     This class holds configuration information and provides the
     following methods:
 
-    needConfig() - returns true if configuration information is incomplete
-    readConfig() - reads configuration information from file
+    need_config() - returns true if configuration information is incomplete
+    read_config() - reads configuration information from file
     setConfig(config_info_dict) - sets configuration information
-    writeConfiguration - writes configuration information to file
-    writeDownloadQueue - writes download queue to file
+    write_configuration - writes configuration information to file
+    write_download_queue - writes download queue to file
 
     The actual configuration information is stored as a two-level dictionary.
     First-level keys are config sections, second-level keys are config
@@ -79,7 +70,6 @@ class Config:
 
     def __init__(self, filename, data_dir):
 
-        self.frame = None
         self.filename = filename
         self.data_dir = data_dir
         self.parser = configparser.RawConfigParser()
@@ -87,10 +77,10 @@ class Config:
         try:
             self.parser.read([self.filename], encoding="utf-8")
         except UnicodeDecodeError:
-            self.convertConfig()
+            self.convert_config()
             self.parser.read([self.filename], encoding="utf-8")
 
-        LOGDIR = os.path.join(data_dir, "logs")
+        log_dir = os.path.join(data_dir, "logs")
 
         self.sections = {
             "server": {
@@ -107,7 +97,7 @@ class Config:
                 "banlist": [],
                 "ignorelist": [],
                 "ipignorelist": {},
-                "ipblocklist": {"72.172.88.*": "MediaDefender Bots"},
+                "ipblocklist": {},
                 "autojoin": ["nicotine"],
                 "autoaway": 15,
                 "private_chatrooms": False
@@ -213,9 +203,9 @@ class Config:
             "logging": {
                 "debug": False,
                 "debugmodes": [0, 1],
-                "debuglogsdir": os.path.join(LOGDIR, "debug"),
+                "debuglogsdir": os.path.join(log_dir, "debug"),
                 "logcollapsed": False,
-                "transferslogsdir": os.path.join(LOGDIR, "transfers"),
+                "transferslogsdir": os.path.join(log_dir, "transfers"),
                 "rooms_timestamp": "%H:%M:%S",
                 "private_timestamp": "%Y-%m-%d %H:%M:%S",
                 "log_timestamp": "%Y-%m-%d %H:%M:%S",
@@ -224,8 +214,8 @@ class Config:
                 "chatrooms": False,
                 "transfers": False,
                 "debug_file_output": False,
-                "roomlogsdir": os.path.join(LOGDIR, "rooms"),
-                "privatelogsdir": os.path.join(LOGDIR, "private"),
+                "roomlogsdir": os.path.join(log_dir, "rooms"),
+                "privatelogsdir": os.path.join(log_dir, "private"),
                 "readroomlogs": True,
                 "readroomlines": 15,
                 "readprivatelines": 15,
@@ -408,7 +398,7 @@ class Config:
 
         self.defaults = {}
         for key, value in self.sections.items():
-            if type(value) is dict:
+            if isinstance(value, dict):
                 if key not in self.defaults:
                     self.defaults[key] = {}
 
@@ -424,14 +414,15 @@ class Config:
         except Exception:
             self.aliases = {}
 
-    def convertConfig(self):
+    def convert_config(self):
         """ Converts the config to utf-8.
         Mainly for upgrading Windows build. (22 July, 2020) """
 
         try:
             from chardet import detect
         except ImportError:
-            return
+            print("Failed to convert config file to UTF-8. Please install python3-chardet and start Nicotine+ again.")
+            sys.exit()
 
         os.rename(self.filename, self.filename + ".conv")
 
@@ -447,7 +438,7 @@ class Config:
 
         os.remove(self.filename + ".conv")
 
-    def needConfig(self):
+    def need_config(self):
 
         errorlevel = 0
 
@@ -455,7 +446,7 @@ class Config:
             for i in self.sections:
                 for j in self.sections[i]:
 
-                    if type(self.sections[i][j]) not in [type(None), type("")]:
+                    if not isinstance(self.sections[i][j], (type(None), type(""))):
                         continue
 
                     if self.sections[i][j] is None or self.sections[i][j] == '' \
@@ -466,8 +457,8 @@ class Config:
                         if self.sections[i][j] is None and self.defaults[i][j] is not None:
 
                             self.sections[i][j] = self.defaults[i][j]
-                            self.frame.logMessage(
-                                _("Config option reset to default: Section: %(section)s, Option: %(option)s, to: %(default)s") % {
+                            log.add(
+                                _("Config option reset to default: Section: %(section)s, Option: %(option)s, to: %(default)s"), {
                                     'section': i,
                                     'option': j,
                                     'default': self.sections[i][j]
@@ -479,26 +470,17 @@ class Config:
                         else:
 
                             if errorlevel < 2:
-                                self.frame.logMessage(
-                                    _("You need to configure your settings (Server, Username, Password, Download Directory) before connecting...")
-                                )
+                                log.add(_("You need to configure your settings (Server, Username, Password, Download Directory) before connecting..."))
                                 errorlevel = 2
 
-                            if self.frame.settingswindow is not None:
-                                self.frame.settingswindow.InvalidSettings(i, j)
-
         except Exception as error:
-            message = _("Config error: %s") % error
-            self.frame.logMessage(message)
+            log.add(_("Config error: %s"), error)
             if errorlevel < 3:
                 errorlevel = 3
 
-        if errorlevel > 1 and self.frame.settingswindow is not None:
-            self.frame.settingswindow.SetSettings(self.sections)
-
         return errorlevel
 
-    def readConfig(self):
+    def read_config(self):
 
         self.sections['transfers']['downloads'] = []
 
@@ -507,12 +489,12 @@ class Config:
             try:
                 handle = open(os.path.join(self.data_dir, 'transfers.pickle'), 'rb')
             except IOError as inst:
-                log.addwarning(_("Something went wrong while opening your transfer list: %(error)s") % {'error': str(inst)})
+                log.add_warning(_("Something went wrong while opening your transfer list: %(error)s"), {'error': str(inst)})
             else:
                 try:
                     self.sections['transfers']['downloads'] = RestrictedUnpickler(handle).load()
                 except Exception as inst:
-                    log.addwarning(_("Something went wrong while reading your transfer list: %(error)s") % {'error': str(inst)})
+                    log.add_warning(_("Something went wrong while reading your transfer list: %(error)s"), {'error': str(inst)})
             try:
                 handle.close()
             except Exception:
@@ -523,75 +505,75 @@ class Config:
             if not os.path.isdir(path):
                 os.makedirs(path)
         except OSError as msg:
-            log.addwarning("Can't create directory '%s', reported error: %s" % (path, msg))
+            log.add_warning("Can't create directory '%s', reported error: %s", (path, msg))
 
         try:
             if not os.path.isdir(self.data_dir):
                 os.makedirs(self.data_dir)
         except OSError as msg:
-            log.addwarning("Can't create directory '%s', reported error: %s" % (path, msg))
+            log.add_warning("Can't create directory '%s', reported error: %s", (path, msg))
 
         # Transition from 1.2.16 -> 1.4.0
         # Do the cleanup early so we don't get the annoying
         # 'Unknown config option ...' message
-        self.removeOldOption("transfers", "pmqueueddir")
-        self.removeOldOption("server", "lastportstatuscheck")
-        self.removeOldOption("server", "serverlist")
-        self.removeOldOption("userinfo", "descrutf8")
-        self.removeOldOption("ui", "enabletrans")
-        self.removeOldOption("ui", "mozembed")
-        self.removeOldOption("ui", "open_in_mozembed")
-        self.removeOldOption("ui", "tooltips")
-        self.removeOldOption("ui", "transalpha")
-        self.removeOldOption("ui", "transfilter")
-        self.removeOldOption("ui", "transtint")
-        self.removeOldOption("language", "language")
-        self.removeOldOption("language", "setlanguage")
-        self.removeOldSection("language")
+        self.remove_old_option("transfers", "pmqueueddir")
+        self.remove_old_option("server", "lastportstatuscheck")
+        self.remove_old_option("server", "serverlist")
+        self.remove_old_option("userinfo", "descrutf8")
+        self.remove_old_option("ui", "enabletrans")
+        self.remove_old_option("ui", "mozembed")
+        self.remove_old_option("ui", "open_in_mozembed")
+        self.remove_old_option("ui", "tooltips")
+        self.remove_old_option("ui", "transalpha")
+        self.remove_old_option("ui", "transfilter")
+        self.remove_old_option("ui", "transtint")
+        self.remove_old_option("language", "language")
+        self.remove_old_option("language", "setlanguage")
+        self.remove_old_section("language")
 
         # Transition from 1.4.1 -> 1.4.2
-        self.removeOldOption("columns", "downloads")
-        self.removeOldOption("columns", "uploads")
+        self.remove_old_option("columns", "downloads")
+        self.remove_old_option("columns", "uploads")
 
         # Remove old encoding settings (1.4.3)
-        self.removeOldOption("server", "enc")
-        self.removeOldOption("server", "fallbackencodings")
-        self.removeOldOption("server", "roomencoding")
-        self.removeOldOption("server", "userencoding")
+        self.remove_old_option("server", "enc")
+        self.remove_old_option("server", "fallbackencodings")
+        self.remove_old_option("server", "roomencoding")
+        self.remove_old_option("server", "userencoding")
 
         # Remove soundcommand config, replaced by GSound (1.4.3)
-        self.removeOldOption("ui", "soundcommand")
+        self.remove_old_option("ui", "soundcommand")
 
         # Remove old column widths in preparation for "group by folder"-feature
-        self.removeOldOption("columns", "search")
-        self.removeOldOption("columns", "search_widths")
-        self.removeOldOption("columns", "downloads_columns")
-        self.removeOldOption("columns", "downloads_widths")
-        self.removeOldOption("columns", "uploads_columns")
-        self.removeOldOption("columns", "uploads_widths")
+        self.remove_old_option("columns", "search")
+        self.remove_old_option("columns", "search_widths")
+        self.remove_old_option("columns", "downloads_columns")
+        self.remove_old_option("columns", "downloads_widths")
+        self.remove_old_option("columns", "uploads_columns")
+        self.remove_old_option("columns", "uploads_widths")
 
         # Remove auto-retry failed downloads-option, this is now default behavior
-        self.removeOldOption("transfers", "autoretry_downloads")
+        self.remove_old_option("transfers", "autoretry_downloads")
 
         # Remove old notification/sound settings
-        self.removeOldOption("transfers", "shownotification")
-        self.removeOldOption("transfers", "shownotificationperfolder")
-        self.removeOldOption("ui", "soundenabled")
-        self.removeOldOption("ui", "soundtheme")
-        self.removeOldOption("ui", "tab_colors")
-        self.removeOldOption("ui", "tab_icons")
+        self.remove_old_option("transfers", "shownotification")
+        self.remove_old_option("transfers", "shownotificationperfolder")
+        self.remove_old_option("ui", "soundenabled")
+        self.remove_old_option("ui", "soundtheme")
+        self.remove_old_option("ui", "tab_colors")
+        self.remove_old_option("ui", "tab_icons")
 
         # Remove dropped offline user text color in search results
-        self.removeOldOption("ui", "searchoffline")
+        self.remove_old_option("ui", "searchoffline")
 
         # Seems to be superseded by ("server", "private_chatrooms")
-        self.removeOldOption("private_rooms", "enabled")
+        self.remove_old_option("private_rooms", "enabled")
 
         # Remove everything ticker-related, no longer necessary after the introduction of room walls
-        self.removeOldSection("ticker")
+        self.remove_old_section("ticker")
 
         # Remove old log folder option, superseded by individual log folders for transfers and debug messages
-        self.removeOldOption("logging", "logsdir")
+        self.remove_old_option("logging", "logsdir")
 
         # Checking for unknown section/options
         unknown1 = [
@@ -627,9 +609,9 @@ class Config:
             for j in self.parser.options(i):
                 val = self.parser.get(i, j, raw=1)
                 if i not in self.sections:
-                    log.addwarning(_("Unknown config section '%s'") % i)
+                    log.add_warning(_("Unknown config section '%s'"), i)
                 elif j not in self.sections[i] and not (j == "filter" or i in ('plugins',)):
-                    log.addwarning(_("Unknown config option '%(option)s' in section '%(section)s'") % {'option': j, 'section': i})
+                    log.add_warning(_("Unknown config option '%(option)s' in section '%(section)s'"), {'option': j, 'section': i})
                 elif j in unknown1 or (i in unknown2 and j not in unknown2[i]):
                     if val is not None and val != "None":
                         self.sections[i][j] = val
@@ -640,195 +622,20 @@ class Config:
                         self.sections[i][j] = literal_eval(val)
                     except Exception:
                         self.sections[i][j] = None
-                        log.addwarning("CONFIG ERROR: Couldn't decode '%s' section '%s' value '%s'" % (str(j), str(i), str(val)))
-
-        # Convert fs-based shared to virtual shared (pre 1.4.0)
-        def _convert_to_virtual(x):
-            if isinstance(x, tuple):
-                return x
-            virtual = x.replace('/', '_').replace('\\', '_').strip('_')
-            log.addwarning("Renaming shared folder '%s' to '%s'. A rescan of your share is required." % (x, virtual))
-            return (virtual, x)
-
-        self.sections["transfers"]["shared"] = [_convert_to_virtual(x) for x in self.sections["transfers"]["shared"]]
-        self.sections["transfers"]["buddyshared"] = [_convert_to_virtual(x) for x in self.sections["transfers"]["buddyshared"]]
-
-        sharedfiles = None
-        bsharedfiles = None
-        sharedfilesstreams = None
-        bsharedfilesstreams = None
-        wordindex = None
-        bwordindex = None
-        fileindex = None
-        bfileindex = None
-        sharedmtimes = None
-        bsharedmtimes = None
-
-        shelves = [
-            os.path.join(self.data_dir, "files.db"),
-            os.path.join(self.data_dir, "buddyfiles.db"),
-            os.path.join(self.data_dir, "streams.db"),
-            os.path.join(self.data_dir, "buddystreams.db"),
-            os.path.join(self.data_dir, "wordindex.db"),
-            os.path.join(self.data_dir, "buddywordindex.db"),
-            os.path.join(self.data_dir, "fileindex.db"),
-            os.path.join(self.data_dir, "buddyfileindex.db"),
-            os.path.join(self.data_dir, "mtimes.db"),
-            os.path.join(self.data_dir, "buddymtimes.db")
-        ]
-
-        _opened_shelves = []
-        _errors = []
-        for shelvefile in shelves:
-            try:
-                _opened_shelves.append(shelve.open(shelvefile, protocol=pickle.HIGHEST_PROTOCOL))
-            except Exception:
-                _errors.append(shelvefile)
-                try:
-                    os.unlink(shelvefile)
-                    _opened_shelves.append(shelve.open(shelvefile, flag='n', protocol=pickle.HIGHEST_PROTOCOL))
-                except Exception as ex:
-                    print(("Failed to unlink %s: %s" % (shelvefile, ex)))
-
-        sharedfiles = _opened_shelves.pop(0)
-        bsharedfiles = _opened_shelves.pop(0)
-        sharedfilesstreams = _opened_shelves.pop(0)
-        bsharedfilesstreams = _opened_shelves.pop(0)
-        wordindex = _opened_shelves.pop(0)
-        bwordindex = _opened_shelves.pop(0)
-        fileindex = _opened_shelves.pop(0)
-        bfileindex = _opened_shelves.pop(0)
-        sharedmtimes = _opened_shelves.pop(0)
-        bsharedmtimes = _opened_shelves.pop(0)
-
-        if _errors:
-            log.addwarning(_("Failed to process the following databases: %(names)s") % {'names': '\n'.join(_errors)})
-
-            files = self.clearShares(
-                sharedfiles, bsharedfiles, sharedfilesstreams, bsharedfilesstreams,
-                wordindex, bwordindex, fileindex, bfileindex, sharedmtimes, bsharedmtimes
-            )
-
-            if files is not None:
-                sharedfiles, bsharedfiles, sharedfilesstreams, bsharedfilesstreams, wordindex, bwordindex, fileindex, bfileindex, sharedmtimes, bsharedmtimes = files
-
-            log.addwarning(_("Shared files database seems to be corrupted, rescan your shares"))
-
-        self.sections["transfers"]["sharedfiles"] = sharedfiles
-        self.sections["transfers"]["sharedfilesstreams"] = sharedfilesstreams
-        self.sections["transfers"]["wordindex"] = wordindex
-        self.sections["transfers"]["fileindex"] = fileindex
-        self.sections["transfers"]["sharedmtimes"] = sharedmtimes
-
-        self.sections["transfers"]["bsharedfiles"] = bsharedfiles
-        self.sections["transfers"]["bsharedfilesstreams"] = bsharedfilesstreams
-        self.sections["transfers"]["bwordindex"] = bwordindex
-        self.sections["transfers"]["bfileindex"] = bfileindex
-        self.sections["transfers"]["bsharedmtimes"] = bsharedmtimes
+                        log.add_warning("CONFIG ERROR: Couldn't decode '%s' section '%s' value '%s'", (str(j), str(i), str(val)))
 
         # Setting the port range in numerical order
         self.sections["server"]["portrange"] = (min(self.sections["server"]["portrange"]), max(self.sections["server"]["portrange"]))
 
-    def removeOldOption(self, section, option):
-        if section in self.parser.sections():
-            if option in self.parser.options(section):
-                self.parser.remove_option(section, option)
+    def remove_old_option(self, section, option):
+        if section in self.parser.sections() and option in self.parser.options(section):
+            self.parser.remove_option(section, option)
 
-    def removeOldSection(self, section):
+    def remove_old_section(self, section):
         if section in self.parser.sections():
             self.parser.remove_section(section)
 
-    def clearShares(
-        self, sharedfiles, bsharedfiles, sharedfilesstreams, bsharedfilesstreams,
-        wordindex, bwordindex, fileindex, bfileindex, sharedmtimes, bsharedmtimes
-    ):
-
-        try:
-            if sharedfiles:
-                sharedfiles.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'files.db'))
-            except Exception:
-                pass
-            sharedfiles = shelve.open(os.path.join(self.data_dir, "files.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if bsharedfiles:
-                bsharedfiles.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'buddyfiles.db'))
-            except Exception:
-                pass
-            bsharedfiles = shelve.open(os.path.join(self.data_dir, "buddyfiles.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if sharedfilesstreams:
-                sharedfilesstreams.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'streams.db'))
-            except Exception:
-                pass
-            sharedfilesstreams = shelve.open(os.path.join(self.data_dir, "streams.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if bsharedfilesstreams:
-                bsharedfilesstreams.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'buddystreams.db'))
-            except Exception:
-                pass
-            bsharedfilesstreams = shelve.open(os.path.join(self.data_dir, "buddystreams.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if wordindex:
-                wordindex.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'wordindex.db'))
-            except Exception:
-                pass
-            wordindex = shelve.open(os.path.join(self.data_dir, "wordindex.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if bwordindex:
-                bwordindex.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'buddywordindex.db'))
-            except Exception:
-                pass
-            bwordindex = shelve.open(os.path.join(self.data_dir, "buddywordindex.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if fileindex:
-                fileindex.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'fileindex.db'))
-            except Exception:
-                pass
-            fileindex = shelve.open(os.path.join(self.data_dir, "fileindex.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if bfileindex:
-                bfileindex.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'buddyfileindex.db'))
-            except Exception:
-                pass
-            bfileindex = shelve.open(os.path.join(self.data_dir, "buddyfileindex.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if sharedmtimes:
-                sharedmtimes.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'mtimes.db'))
-            except Exception:
-                pass
-            sharedmtimes = shelve.open(os.path.join(self.data_dir, "mtimes.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-            if bsharedmtimes:
-                bsharedmtimes.close()
-            try:
-                os.unlink(os.path.join(self.data_dir, 'buddymtimes.db'))
-            except Exception:
-                pass
-            bsharedmtimes = shelve.open(os.path.join(self.data_dir, "buddymtimes.db"), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-        except Exception as error:
-            log.addwarning(_("Error while writing database files: %s") % error)
-            return None
-        return sharedfiles, bsharedfiles, sharedfilesstreams, bsharedfilesstreams, wordindex, bwordindex, fileindex, bfileindex, sharedmtimes, bsharedmtimes
-
-    def writeDownloadQueue(self):
+    def write_download_queue(self):
 
         realfile = os.path.join(self.data_dir, 'transfers.pickle')
         tmpfile = realfile + '.tmp'
@@ -836,7 +643,7 @@ class Config:
         try:
             handle = open(tmpfile, 'wb')
         except Exception as inst:
-            log.addwarning(_("Something went wrong while opening your transfer list: %(error)s") % {'error': str(inst)})
+            log.add_warning(_("Something went wrong while opening your transfer list: %(error)s"), {'error': str(inst)})
         else:
             try:
                 pickle.dump(self.sections['transfers']['downloads'], handle, protocol=pickle.HIGHEST_PROTOCOL)
@@ -853,14 +660,14 @@ class Config:
                     os.rename(realfile, backupfile)
                     os.rename(tmpfile, realfile)
             except Exception as inst:
-                log.addwarning(_("Something went wrong while writing your transfer list: %(error)s") % {'error': str(inst)})
+                log.add_warning(_("Something went wrong while writing your transfer list: %(error)s"), {'error': str(inst)})
         finally:
             try:
                 handle.close()
             except Exception:
                 pass
 
-    def writeConfiguration(self):
+    def write_configuration(self):
 
         external_sections = [
             "sharedfiles", "sharedfilesstreams", "wordindex", "fileindex",
@@ -882,20 +689,20 @@ class Config:
             if not os.path.isdir(path):
                 os.makedirs(path)
         except OSError as msg:
-            log.addwarning(_("Can't create directory '%(path)s', reported error: %(error)s") % {'path': path, 'error': msg})
+            log.add_warning(_("Can't create directory '%(path)s', reported error: %(error)s"), {'path': path, 'error': msg})
 
         oldumask = os.umask(0o077)
 
         try:
             f = open(self.filename + ".new", "w", encoding="utf-8")
         except IOError as e:
-            log.addwarning(_("Can't save config file, I/O error: %s") % e)
+            log.add_warning(_("Can't save config file, I/O error: %s"), e)
             return
         else:
             try:
                 self.parser.write(f)
             except IOError as e:
-                log.addwarning(_("Can't save config file, I/O error: %s") % e)
+                log.add_warning(_("Can't save config file, I/O error: %s"), e)
                 return
             else:
                 f.close()
@@ -915,115 +722,74 @@ class Config:
                     if os.path.exists(self.filename + ".old"):
                         os.remove(self.filename + ".old")
                 except OSError:
-                    log.addwarning(_("Can't remove %s" % self.filename + ".old"))
+                    log.add_warning(_("Can't remove %s", self.filename + ".old"))
                 try:
                     os.rename(self.filename, self.filename + ".old")
                 except OSError as error:
-                    log.addwarning(_("Can't back config file up, error: %s") % error)
+                    log.add_warning(_("Can't back config file up, error: %s"), error)
         except OSError:
             pass
 
         try:
             os.rename(self.filename + ".new", self.filename)
         except OSError as error:
-            log.addwarning(_("Can't rename config file, error: %s") % error)
+            log.add_warning(_("Can't rename config file, error: %s"), error)
 
-    def writeConfigBackup(self, filename=None):
+    def write_config_backup(self, filename=None):
 
         if filename is None:
-            filename = "%s backup %s.tar.bz2" % (self.filename, time.strftime("%Y-%m-%d %H:%M:%S"))
+            filename = "%s backup %s.tar.bz2", (self.filename, time.strftime("%Y-%m-%d %H:%M:%S"))
         else:
             if filename[-8:-1] != ".tar.bz2":
                 filename += ".tar.bz2"
         try:
             if os.path.exists(filename):
-                raise BaseException("File %s exists" % filename)
+                raise FileExistsError("File %s exists", filename)
+
             import tarfile
             tar = tarfile.open(filename, "w:bz2")
+
             if not os.path.exists(self.filename):
-                raise BaseException("Config file missing")
+                raise FileNotFoundError("Config file missing")
+
             tar.add(self.filename)
+
             if os.path.exists(self.filename + ".alias"):
                 tar.add(self.filename + ".alias")
 
             tar.close()
         except Exception as e:
             print(e)
-            return (1, "Cannot write backup archive: %s" % e)
+            return (1, "Cannot write backup archive: %s", e)
 
         return (0, filename)
 
-    def setBuddyShares(self, files, streams, wordindex, fileindex, mtimes):
-
-        storable_objects = [
-            (files, "bsharedfiles", "buddyfiles.db"),
-            (streams, "bsharedfilesstreams", "buddystreams.db"),
-            (mtimes, "bsharedmtimes", "buddymtimes.db"),
-            (wordindex, "bwordindex", "buddywordindex.db"),
-            (fileindex, "bfileindex", "buddyfileindex.db")
-        ]
-
-        self.storeObjects(storable_objects)
-
-    def setShares(self, files, streams, wordindex, fileindex, mtimes):
-
-        storable_objects = [
-            (files, "sharedfiles", "files.db"),
-            (streams, "sharedfilesstreams", "streams.db"),
-            (mtimes, "sharedmtimes", "mtimes.db"),
-            (wordindex, "wordindex", "wordindex.db"),
-            (fileindex, "fileindex", "fileindex.db")
-        ]
-
-        self.storeObjects(storable_objects)
-
-    def storeObjects(self, storable_objects):
-
-        for (source, destination, filename) in storable_objects:
-            try:
-                self.sections["transfers"][destination].close()
-                self.sections["transfers"][destination] = shelve.open(os.path.join(self.data_dir, filename), flag='n', protocol=pickle.HIGHEST_PROTOCOL)
-
-                if "fileindex" in destination:
-                    index = 0
-
-                    for value in source:
-                        # The file index db is a list
-                        self.sections["transfers"][destination][str(index)] = value
-                        index += 1
-                else:
-                    for key in source:
-                        self.sections["transfers"][destination][key] = source[key]
-            except Exception as e:
-                log.addwarning(_("Can't save %s: %s") % (filename, e))
-                return
-
-    def writeAliases(self):
+    def write_aliases(self):
 
         try:
             f = open(self.filename + ".alias", "wb")
         except Exception as e:
-            log.addwarning(_("Something went wrong while opening your alias file: %s") % e)
+            log.add_warning(_("Something went wrong while opening your alias file: %s"), e)
         else:
             try:
                 pickle.dump(self.aliases, f, protocol=pickle.HIGHEST_PROTOCOL)
                 f.close()
             except Exception as e:
-                log.addwarning(_("Something went wrong while saving your alias file: %s") % e)
+                log.add_warning(_("Something went wrong while saving your alias file: %s"), e)
         finally:
             try:
                 f.close()
             except Exception:
                 pass
 
-    def AddAlias(self, rest):
+    def add_alias(self, rest):
         if rest:
             args = rest.split(" ", 1)
             if len(args) == 2:
                 if args[0] in ("alias", "unalias"):
                     return "I will not alias that!\n"
                 self.aliases[args[0]] = args[1]
-                self.writeAliases()
+                self.write_aliases()
             if args[0] in self.aliases:
                 return "Alias %s: %s\n" % (args[0], self.aliases[args[0]])
             else:
@@ -1034,11 +800,11 @@ class Config:
                 m = m + "%s: %s\n" % (key, value)
             return m + "\n"
 
-    def Unalias(self, rest):
+    def unalias(self, rest):
         if rest and rest in self.aliases:
             x = self.aliases[rest]
             del self.aliases[rest]
-            self.writeAliases()
+            self.write_aliases()
             return _("Removed alias %(alias)s: %(action)s\n") % {'alias': rest, 'action': x}
         else:
             return _("No such alias (%(alias)s)\n") % {'alias': rest}
