@@ -25,15 +25,15 @@ from os.path import getsize
 from os.path import join
 
 from gi.repository import GLib
-from gi.repository import GObject as gobject
-from gi.repository import Gtk as gtk
+from gi.repository import GObject
+from gi.repository import Gtk
 
 import _thread
-from pynicotine.gtkgui.dirchooser import ChooseDir
-from pynicotine.gtkgui.dialogs import ComboBoxDialog
-from pynicotine.gtkgui.utils import HumanSize
-from pynicotine.gtkgui.utils import InitialiseColumns
-from pynicotine.gtkgui.utils import OpenUri
+from pynicotine.gtkgui.dirchooser import choose_dir
+from pynicotine.gtkgui.dialogs import combo_box_dialog
+from pynicotine.gtkgui.utils import human_size
+from pynicotine.gtkgui.utils import initialise_columns
+from pynicotine.gtkgui.utils import open_uri
 
 
 def dirstats(directory):
@@ -75,7 +75,7 @@ class FastConfigureAssistant(object):
         self.initphase = True  # don't respond to signals unless False
         self.config = frame.np.config
 
-        builder = gtk.Builder()
+        builder = Gtk.Builder()
 
         builder.set_translation_domain('nicotine')
         builder.add_from_file(os.path.join(os.path.dirname(os.path.realpath(__file__)), "ui", "fastconfigure.ui"))
@@ -88,24 +88,24 @@ class FastConfigureAssistant(object):
 
         for i in builder.get_objects():
             try:
-                self.kids[gtk.Buildable.get_name(i)] = i
+                self.kids[Gtk.Buildable.get_name(i)] = i
             except TypeError:
                 pass
 
         # Page specific, sharepage
         # The last column is the raw byte/unicode object
         # for the folder (not shown)
-        self.sharelist = gtk.ListStore(
-            gobject.TYPE_STRING,
-            gobject.TYPE_STRING,
-            gobject.TYPE_STRING,
-            gobject.TYPE_STRING,
-            gobject.TYPE_STRING,
-            gobject.TYPE_STRING,
-            gobject.TYPE_STRING
+        self.sharelist = Gtk.ListStore(
+            GObject.TYPE_STRING,
+            GObject.TYPE_STRING,
+            GObject.TYPE_STRING,
+            GObject.TYPE_STRING,
+            GObject.TYPE_STRING,
+            GObject.TYPE_STRING,
+            GObject.TYPE_STRING
         )
 
-        InitialiseColumns(
+        initialise_columns(
             self.kids['shareddirectoriestree'],
             [_("Virtual Directory"), 0, "text"],
             [_("Directory"), 0, "text"],
@@ -117,7 +117,7 @@ class FastConfigureAssistant(object):
 
         self.kids['shareddirectoriestree'].set_model(self.sharelist)
         self.kids['shareddirectoriestree'].get_selection().set_mode(
-            gtk.SelectionMode.MULTIPLE
+            Gtk.SelectionMode.MULTIPLE
         )
 
         self.initphase = False
@@ -208,25 +208,25 @@ class FastConfigureAssistant(object):
             else:
                 self.config.sections["transfers"]["shared"] = self.getshareddirs()
 
-    def OnClose(self, widget):
+    def on_close(self, widget):
         self.window.hide()
 
-    def OnApply(self, widget):
+    def on_apply(self, widget):
         self.store()
         self.window.hide()
 
         # Rescan public shares if needed
         if not self.config.sections["transfers"]["friendsonly"]:
-            self.frame.OnRescan()
+            self.frame.on_rescan()
 
         # Rescan buddy shares if needed
         if self.config.sections["transfers"]["enablebuddyshares"]:
-            self.frame.OnBuddyRescan()
+            self.frame.on_buddy_rescan()
 
-        if not self.frame.np.serverconn:
-            self.frame.OnConnect(-1)
+        if not self.frame.np.active_server_conn:
+            self.frame.on_connect(-1)
 
-    def OnCancel(self, widget):
+    def on_cancel(self, widget):
         self.window.hide()
 
     def resetcompleteness(self, page=None):
@@ -241,7 +241,7 @@ class FastConfigureAssistant(object):
             if not page:
                 return
 
-        name = gtk.Buildable.get_name(page)
+        name = Gtk.Buildable.get_name(page)
 
         if name == 'welcomepage':
             complete = True
@@ -283,14 +283,14 @@ class FastConfigureAssistant(object):
 
         self.window.set_page_complete(page, complete)
 
-    def OnPrepare(self, widget, page):
+    def on_prepare(self, widget, page):
         self.window.set_page_complete(page, False)
         self.resetcompleteness(page)
 
-    def OnEntryChanged(self, widget, param1=None, param2=None, param3=None):
+    def on_entry_changed(self, widget, param1=None, param2=None, param3=None):
         self.resetcompleteness()
 
-    def OnEntryPaste(self, user_data):
+    def on_entry_paste(self, user_data):
         """
             Hack to workaround if the user paste is username or password.
             The "paste-clipboard" event of the GtkEntry doesn't seems to have a length after a text is pasted into it.
@@ -299,7 +299,7 @@ class FastConfigureAssistant(object):
         """
 
         # Get the name of the GtkEditable object
-        name = gtk.Buildable.get_name(user_data)
+        name = Gtk.Buildable.get_name(user_data)
 
         # Set the text of the corresponding entry
         self.kids[name].set_text(user_data.get_text())
@@ -309,30 +309,30 @@ class FastConfigureAssistant(object):
 
     def getshareddirs(self):
 
-        iter = self.sharelist.get_iter_first()
+        iterator = self.sharelist.get_iter_first()
         dirs = []
 
-        while iter is not None:
+        while iterator is not None:
             dirs.append(
                 (
-                    self.sharelist.get_value(iter, 0),
-                    self.sharelist.get_value(iter, 6)
+                    self.sharelist.get_value(iterator, 0),
+                    self.sharelist.get_value(iterator, 6)
                 )
             )
-            iter = self.sharelist.iter_next(iter)
+            iterator = self.sharelist.iter_next(iterator)
 
         return dirs
 
     def addshareddir(self, directory):
 
-        iter = self.sharelist.get_iter_first()
+        iterator = self.sharelist.get_iter_first()
 
-        while iter is not None:
+        while iterator is not None:
 
-            if directory[1] == self.sharelist.get_value(iter, 6):
+            if directory[1] == self.sharelist.get_value(iterator, 6):
                 return
 
-            iter = self.sharelist.iter_next(iter)
+            iterator = self.sharelist.iter_next(iterator)
 
         self.sharelist.append([
             directory[0],
@@ -365,7 +365,7 @@ class FastConfigureAssistant(object):
         GLib.idle_add(
             self._updatedirstats,
             directory,
-            HumanSize(size),
+            human_size(size),
             files,
             subdirs,
             extstring
@@ -373,36 +373,36 @@ class FastConfigureAssistant(object):
 
     def _updatedirstats(self, directory, size, files, subdirs, extensions):
 
-        iter = self.sharelist.get_iter_first()
+        iterator = self.sharelist.get_iter_first()
 
-        while iter is not None:
+        while iterator is not None:
 
-            if directory[1] == self.sharelist.get_value(iter, 6):
+            if directory[1] == self.sharelist.get_value(iterator, 6):
 
                 self.sharelist.insert(0, [
                     directory[0],
                     directory[1],
-                    HumanSize(size),
+                    human_size(size),
                     str(files),
                     str(subdirs),
                     extensions,
                     directory[1]
                 ])
 
-                self.sharelist.remove(iter)
+                self.sharelist.remove(iterator)
                 return
 
-            iter = self.sharelist.iter_next(iter)
+            iterator = self.sharelist.iter_next(iterator)
 
-    def OnButtonPressed(self, widget):
+    def on_button_pressed(self, widget):
 
         if self.initphase:
             return
 
-        name = gtk.Buildable.get_name(widget)
+        name = Gtk.Buildable.get_name(widget)
 
         if name == "checkmyport":
-            OpenUri(
+            open_uri(
                 '='.join([
                     'http://tools.slsknet.org/porttest.php?port',
                     str(self.frame.np.waitport)
@@ -412,7 +412,7 @@ class FastConfigureAssistant(object):
 
         if name == "addshare":
 
-            selected = ChooseDir(
+            selected = choose_dir(
                 self.window.get_toplevel(),
                 title=_("Add a shared directory")
             )
@@ -421,7 +421,7 @@ class FastConfigureAssistant(object):
 
                 for directory in selected:
 
-                    virtual = ComboBoxDialog(
+                    virtual = combo_box_dialog(
                         parent=self.frame.MainWindow,
                         title=_("Virtual name"),
                         message=_("Enter virtual name for '%(dir)s':") % {'dir': directory}
@@ -430,34 +430,33 @@ class FastConfigureAssistant(object):
                     # If the virtual name is empty
                     if virtual == '' or virtual is None:
 
-                        dlg = gtk.MessageDialog(
+                        dlg = Gtk.MessageDialog(
                             transient_for=self.window,
                             flags=0,
-                            type=gtk.MessageType.WARNING,
-                            buttons=gtk.ButtonsType.OK,
+                            type=Gtk.MessageType.WARNING,
+                            buttons=Gtk.ButtonsType.OK,
                             text=_("Warning")
                         )
                         dlg.format_secondary_text(_("The chosen virtual name is empty"))
                         dlg.run()
                         dlg.destroy()
-                        pass
 
                     else:
                         # We get the current defined shares from the treeview
                         model, paths = self.kids['shareddirectoriestree'].get_selection().get_selected_rows()
 
-                        iter = model.get_iter_first()
+                        iterator = model.get_iter_first()
 
-                        while iter is not None:
+                        while iterator is not None:
 
                             # We reject the share if the virtual share name is already used
-                            if virtual == model.get_value(iter, 0):
+                            if virtual == model.get_value(iterator, 0):
 
-                                dlg = gtk.MessageDialog(
+                                dlg = Gtk.MessageDialog(
                                     transient_for=self.window,
                                     flags=0,
-                                    type=gtk.MessageType.WARNING,
-                                    buttons=gtk.ButtonsType.OK,
+                                    type=Gtk.MessageType.WARNING,
+                                    buttons=Gtk.ButtonsType.OK,
                                     text=_("Warning")
                                 )
                                 dlg.format_secondary_text(_("The chosen virtual name already exists"))
@@ -466,13 +465,13 @@ class FastConfigureAssistant(object):
                                 return
 
                             # We also reject the share if the directory is already used
-                            elif directory == model.get_value(iter, 6):
+                            elif directory == model.get_value(iterator, 6):
 
-                                dlg = gtk.MessageDialog(
+                                dlg = Gtk.MessageDialog(
                                     transient_for=self.window,
                                     flags=0,
-                                    type=gtk.MessageType.WARNING,
-                                    buttons=gtk.ButtonsType.OK,
+                                    type=Gtk.MessageType.WARNING,
+                                    buttons=Gtk.ButtonsType.OK,
                                     text=_("Warning")
                                 )
                                 dlg.format_secondary_text(_("The chosen directory is already shared"))
@@ -481,7 +480,7 @@ class FastConfigureAssistant(object):
                                 return
 
                             else:
-                                iter = model.iter_next(iter)
+                                iterator = model.iter_next(iterator)
 
                         # The share is unique: we can add it
                         self.addshareddir((virtual, directory))
@@ -489,33 +488,33 @@ class FastConfigureAssistant(object):
         if name == "removeshares":
 
             model, paths = self.kids['shareddirectoriestree'].get_selection().get_selected_rows()
-            refs = [gtk.TreeRowReference(model, x) for x in paths]
+            refs = [Gtk.TreeRowReference(model, x) for x in paths]
 
             for i in refs:
                 self.sharelist.remove(self.sharelist.get_iter(i.get_path()))
 
         self.resetcompleteness()
 
-    def OnToggled(self, widget):
+    def on_toggled(self, widget):
 
         if self.initphase:
             return
 
         self.resetcompleteness()
 
-    def OnSpinbuttonChangeValue(self, widget, scrolltype):
+    def on_spinbutton_change_value(self, widget, scrolltype):
 
         if self.initphase:
             return
 
         self.resetcompleteness()
 
-    def OnSpinbuttonValueChanged(self, widget):
+    def on_spinbutton_value_changed(self, widget):
 
         if self.initphase:
             return
 
-        name = gtk.Buildable.get_name(widget)
+        name = Gtk.Buildable.get_name(widget)
 
         if name == "lowerport":
             if widget.get_value() > self.kids['upperport'].get_value():
