@@ -26,11 +26,11 @@ import re
 import sys
 from gettext import gettext as _
 
-from gi.repository import GObject as gobject
-from gi.repository import Gtk as gtk
+from gi.repository import GObject
+from gi.repository import Gtk
 
 from pynicotine.logfacility import log
-from pynicotine.utils import executeCommand
+from pynicotine.utils import execute_command
 
 
 class NowPlaying:
@@ -41,26 +41,26 @@ class NowPlaying:
         # Build the window
         self.frame = frame
 
-        builder = gtk.Builder()
+        builder = Gtk.Builder()
 
         builder.set_translation_domain('nicotine')
         builder.add_from_file(os.path.join(os.path.dirname(os.path.realpath(__file__)), "ui", "nowplaying.ui"))
 
-        self.NowPlaying = builder.get_object("NowPlaying")
+        self.now_playing_dialog = builder.get_object("NowPlayingDialog")
 
         builder.connect_signals(self)
 
         for i in builder.get_objects():
             try:
-                self.__dict__[gtk.Buildable.get_name(i)] = i
+                self.__dict__[Gtk.Buildable.get_name(i)] = i
             except TypeError:
                 pass
 
-        self.NowPlaying.set_transient_for(self.frame.MainWindow)
+        self.now_playing_dialog.set_transient_for(self.frame.MainWindow)
 
-        self.NowPlaying.connect("destroy", self.quit)
-        self.NowPlaying.connect("destroy-event", self.quit)
-        self.NowPlaying.connect("delete-event", self.quit)
+        self.now_playing_dialog.connect("destroy", self.quit)
+        self.now_playing_dialog.connect("destroy-event", self.quit)
+        self.now_playing_dialog.connect("delete-event", self.quit)
 
         self.title_clear()
 
@@ -69,11 +69,11 @@ class NowPlaying:
 
         self.player_replacers = []
 
-        self.OnNPPlayer(None)
-        self.SetPlayer(config["players"]["npplayer"])
+        self.on_np_player(None)
+        self.set_player(config["players"]["npplayer"])
 
         # Default format list
-        self.NPFormat_List = gtk.ListStore(gobject.TYPE_STRING)
+        self.np_format_model = Gtk.ListStore(GObject.TYPE_STRING)
 
         self.defaultlist = [
             "$n",
@@ -85,23 +85,23 @@ class NowPlaying:
         ]
 
         for item in self.defaultlist:
-            self.NPFormat_List.append([str(item)])
+            self.np_format_model.append([str(item)])
 
         # Add custom formats
         if config["players"]["npformatlist"] != []:
             for item in config["players"]["npformatlist"]:
-                self.NPFormat_List.append([str(item)])
+                self.np_format_model.append([str(item)])
 
         # Set the NPFormat model
         self.NPFormat.set_entry_text_column(0)
-        self.NPFormat.set_model(self.NPFormat_List)
+        self.NPFormat.set_model(self.np_format_model)
 
         if config["players"]["npformat"] == "":
             # If there's no default format in the config: set the first of the list
             self.NPFormat.set_active(0)
         else:
             # If there's is a default format in the config: select the right item
-            for (i, v) in enumerate(self.NPFormat_List):
+            for (i, v) in enumerate(self.np_format_model):
                 if v[0] == config["players"]["npformat"]:
                     self.NPFormat.set_active(i)
 
@@ -123,7 +123,7 @@ class NowPlaying:
             "filename": ""
         }
 
-    def SetPlayer(self, player):
+    def set_player(self, player):
 
         if player == "amarok":
             self.NP_amarok.set_active(1)
@@ -147,17 +147,14 @@ class NowPlaying:
         else:
             self.NP_other.set_active(1)
 
-    def OnNPPlayer(self, widget):
+    def on_np_player(self, widget):
 
         isset = False
 
         if self.NP_mpd.get_active():
             self.player_replacers = ["$n", "$t", "$a", "$b", "$f", "$k"]
             isset = True
-        elif self.NP_amarok.get_active():
-            self.player_replacers = ["$n", "$t", "$l", "$a", "$b", "$c", "$k", "$y", "$r", "$f"]
-            isset = True
-        elif self.NP_audacious.get_active():
+        elif self.NP_amarok.get_active() or self.NP_audacious.get_active() or self.NP_xmms2.get_active():
             self.player_replacers = ["$n", "$t", "$l", "$a", "$b", "$c", "$k", "$y", "$r", "$f"]
             isset = True
         elif self.NP_exaile.get_active():
@@ -174,9 +171,6 @@ class NowPlaying:
             self.player_replacers = ["$n", "$p", "$a", "$b", "$t", "$c", "$r", "$k", "$l"]
             self.player_input.set_text(_("Client name (empty = auto) :"))
             isset = True
-        elif self.NP_xmms2.get_active():
-            self.player_replacers = ["$n", "$t", "$l", "$a", "$b", "$c", "$k", "$y", "$r", "$f"]
-            isset = True
         elif self.NP_other.get_active():
             self.player_replacers = ["$n"]
             self.player_input.set_text(_("Command :"))
@@ -221,7 +215,7 @@ class NowPlaying:
         if not isset:
             self.Legend.set_text("")
 
-    def OnNPCancel(self, widget):
+    def on_np_cancel(self, widget):
         self.quit(None)
 
     def quit(self, widget, s=None):
@@ -235,20 +229,20 @@ class NowPlaying:
             if text not in config["players"]["npformatlist"] and text not in self.defaultlist:
                 config["players"]["npformatlist"].append(text)
 
-        self.frame.np.config.writeConfiguration()
+        self.frame.np.config.write_configuration()
 
         # Hide the NowPlaying window
-        self.NowPlaying.hide()
+        self.now_playing_dialog.hide()
         return True
 
-    def OnNPTest(self, widget):
-        self.DisplayNowPlaying(None, 1)
+    def on_np_test(self, widget):
+        self.display_now_playing(None, 1)
 
-    def DisplayNowPlaying(self, widget, test=0, callback=None):
+    def display_now_playing(self, widget, test=0, callback=None):
 
-        self.GetNP(None, test, callback)
+        self.get_np(None, test, callback)
 
-    def GetNP(self, widget, test=None, callback=None):
+    def get_np(self, widget, test=None, callback=None):
 
         self.title_clear()
 
@@ -276,7 +270,7 @@ class NowPlaying:
                 result = self.mpris()
 
         except RuntimeError:
-            log.addwarning(_("ERROR: Could not execute now playing code. Are you sure you picked the right player?"))
+            log.add_warning(_("ERROR: Could not execute now playing code. Are you sure you picked the right player?"))
             result = None
 
         if not result:
@@ -321,7 +315,7 @@ class NowPlaying:
 
         return None
 
-    def OnNPSave(self, widget):
+    def on_np_save(self, widget):
 
         if self.NP_amarok.get_active():
             player = "amarok"
@@ -345,35 +339,35 @@ class NowPlaying:
         self.frame.np.config.sections["players"]["npplayer"] = player
         self.frame.np.config.sections["players"]["npothercommand"] = self.NPCommand.get_text()
         self.frame.np.config.sections["players"]["npformat"] = self.NPFormat.get_child().get_text()
-        self.frame.np.config.writeConfiguration()
+        self.frame.np.config.write_configuration()
 
         self.quit(None)
 
     def mpd(self):
 
-        format = self.NPFormat.get_child().get_text()
+        np_format = self.NPFormat.get_child().get_text()
 
-        if "$a" in format:
+        if "$a" in np_format:
             output = self.mpd_command("%artist%")
             if output:
                 self.title["artist"] = output
 
-        if "$t" in format:
+        if "$t" in np_format:
             output = self.mpd_command("%title%")
             if output:
                 self.title["title"] = output
 
-        if "$n" in format:
+        if "$n" in np_format:
             output = self.mpd_command("%artist% - %title%")
             if output:
                 self.title["nowplaying"] = output
 
-        if "$f" in format:
+        if "$f" in np_format:
             output = self.mpd_command("%file%")
             if output:
                 self.title["filename"] = output
 
-        if "$b" in format:
+        if "$b" in np_format:
             output = self.mpd_command("%album%")
             if output:
                 self.title["album"] = output
@@ -382,7 +376,7 @@ class NowPlaying:
 
     def mpd_command(self, command):
 
-        output = executeCommand("mpc --format $", command, returnoutput=True).decode().split('\n')[0]
+        output = execute_command("mpc --format $", command, returnoutput=True).decode().split('\n')[0]
 
         if output == '' or output.startswith("MPD_HOST") or output.startswith("volume: "):
             return None
@@ -396,7 +390,7 @@ class NowPlaying:
             import dbus
             import dbus.glib
         except ImportError as error:
-            log.addwarning(_("ERROR: amarok: failed to load dbus module: %(error)s") % {"error": error})
+            log.add_warning(_("ERROR: amarok: failed to load dbus module: %(error)s"), {"error": error})
             return None
 
         self.bus = dbus.SessionBus()
@@ -430,7 +424,7 @@ class NowPlaying:
         self.audacious_running = True
 
         if "$n" in slist:
-            artist = self.audacious_command('current-song-tuple-data', 'artist')
+            artist = self.audacious_command('current-song-tuple-data', 'artist') or "?"
             title = self.audacious_command('current-song-tuple-data', 'title')
             if artist and title:
                 self.title["nowplaying"] = artist + ' - ' + title
@@ -479,7 +473,7 @@ class NowPlaying:
             path = self.audacious_command('current-song-filename')  # noqa: F841
 
         if not self.audacious_running:
-            log.addwarning(_("ERROR: audacious: audtool didn't detect a running Audacious session."))
+            log.add_warning(_("ERROR: audacious: audtool didn't detect a running Audacious session."))
             return False
 
         return True
@@ -488,9 +482,9 @@ class NowPlaying:
         """ Wrapper that calls audacious commandline audtool and parse the output """
 
         try:
-            output = executeCommand("audtool %s %s" % (command, subcommand), returnoutput=True).decode().split('\n')[0]
+            output = execute_command("audtool %s %s" % (command, subcommand), returnoutput=True).decode().split('\n')[0]
         except RuntimeError:
-            output = executeCommand("audtool2 %s %s" % (command, subcommand), returnoutput=True).decode().split('\n')[0]
+            output = execute_command("audtool2 %s %s" % (command, subcommand), returnoutput=True).decode().split('\n')[0]
 
         if output.startswith('audtool'):
             output = None
@@ -506,7 +500,7 @@ class NowPlaying:
             import dbus
             import dbus.glib
         except ImportError as error:
-            log.addwarning(_("ERROR: MPRIS: failed to load dbus module: %(error)s") % {"error": error})
+            log.add_warning(_("ERROR: MPRIS: failed to load dbus module: %(error)s"), {"error": error})
             return None
 
         self.bus = dbus.SessionBus()
@@ -528,21 +522,21 @@ class NowPlaying:
                     players.append(name[len(dbus_mpris_service):])
 
             if not players:
-                log.addwarning(_("ERROR: MPRIS: Could not find a suitable MPRIS player."))
+                log.add_warning(_("ERROR: MPRIS: Could not find a suitable MPRIS player."))
                 return None
 
             player = players[0]
             if len(players) > 1:
-                log.addwarning(_("Found multiple MPRIS players: %(players)s. Using: %(player)s") % {'players': players, 'player': player})
+                log.add_warning(_("Found multiple MPRIS players: %(players)s. Using: %(player)s"), {'players': players, 'player': player})
             else:
-                log.addwarning(_("Auto-detected MPRIS player: %s.") % player)
+                log.add_warning(_("Auto-detected MPRIS player: %s."), player)
 
         try:
             player_obj = self.bus.get_object(dbus_mpris_service + player, dbus_mpris_path)
             player_property_obj = dbus.Interface(player_obj, dbus_interface=dbus_property)
             metadata = player_property_obj.Get(dbus_mpris_player_service, "Metadata")
         except Exception as exception:
-            log.addwarning(_("ERROR: MPRIS: Something went wrong while querying %(player)s: %(exception)s") % {'player': player, 'exception': exception})
+            log.add_warning(_("ERROR: MPRIS: Something went wrong while querying %(player)s: %(exception)s"), {'player': player, 'exception': exception})
             return None
 
         self.title['program'] = player
@@ -589,10 +583,10 @@ class NowPlaying:
             try:
                 from win32gui import GetWindowText, FindWindow
             except ImportError as error:
-                log.addwarning(_("ERROR: foobar: failed to load win32gui module: %(error)s") % {"error": error})
+                log.add_warning(_("ERROR: foobar: failed to load win32gui module: %(error)s"), {"error": error})
                 return None
         else:
-            log.addwarning(_("ERROR: foobar: is only supported on windows."))
+            log.add_warning(_("ERROR: foobar: is only supported on windows."))
             return None
 
         wnd_ids = [
@@ -642,13 +636,13 @@ class NowPlaying:
         try:
             conn = http.client.HTTPSConnection("ws.audioscrobbler.com")
         except Exception as error:
-            log.addwarning(_("ERROR: lastfm: Could not connect to audioscrobbler: %(error)s") % {"error": error})
+            log.add_warning(_("ERROR: lastfm: Could not connect to audioscrobbler: %(error)s"), {"error": error})
             return None
 
         try:
             (user, apikey) = self.NPCommand.get_text().split(';')
         except ValueError:
-            log.addwarning(_("ERROR: lastfm: Please provide both your lastfm username and API key"))
+            log.add_warning(_("ERROR: lastfm: Please provide both your lastfm username and API key"))
             return None
 
         conn.request("GET", "/2.0/?method=user.getrecenttracks&user=" + user + "&api_key=" + apikey + "&format=json", headers={"User-Agent": "Nicotine+"})
@@ -656,7 +650,7 @@ class NowPlaying:
         data = resp.read().decode("utf-8")
 
         if resp.status != 200 or resp.reason != "OK":
-            log.addwarning(_("ERROR: lastfm: Could not get recent track from audioscrobbler: %(error)s") % {"error": str(data)})
+            log.add_warning(_("ERROR: lastfm: Could not get recent track from audioscrobbler: %(error)s"), {"error": str(data)})
             return None
 
         json_api = json.loads(data)
@@ -675,11 +669,11 @@ class NowPlaying:
             if othercommand == "":
                 return None
 
-            output = executeCommand(othercommand, returnoutput=True)
+            output = execute_command(othercommand, returnoutput=True)
             self.title["nowplaying"] = output
             return True
         except Exception as error:
-            log.addwarning(_("ERROR: Executing '%(command)s' failed: %(error)s") % {"command": othercommand, "error": error})
+            log.add_warning(_("ERROR: Executing '%(command)s' failed: %(error)s"), {"command": othercommand, "error": error})
             return None
 
     def xmms2(self):
@@ -689,7 +683,7 @@ class NowPlaying:
         try:
             import xmmsclient
         except ImportError as error:
-            log.addwarning(_("ERROR: xmms2: failed to load xmmsclient module: %(error)s") % {"error": error})
+            log.add_warning(_("ERROR: xmms2: failed to load xmmsclient module: %(error)s"), {"error": error})
             return None
 
         xmms = xmmsclient.XMMS("NPP")
@@ -698,21 +692,21 @@ class NowPlaying:
         try:
             xmms.connect(os.getenv("XMMS_PATH"))
         except IOError as error:
-            log.addwarning(_("ERROR: xmms2: connecting failed: %(error)s") % {"error": error})
+            log.add_warning(_("ERROR: xmms2: connecting failed: %(error)s"), {"error": error})
             return None
 
         # Retrieve the current playing entry
         result = xmms.playback_current_id()
         result.wait()
         if result.iserror():
-            log.addwarning(_("ERROR: xmms2: playback current id error: %(error)s") % {"error": result.get_error()})
+            log.add_warning(_("ERROR: xmms2: playback current id error: %(error)s"), {"error": result.get_error()})
             return None
 
-        id = result.value()
+        entry_id = result.value()
 
         # Entry 0 is non valid
-        if id == 0:
-            log.addwarning(_("ERROR: xmms2: nothing is playing"))
+        if entry_id == 0:
+            log.add_warning(_("ERROR: xmms2: nothing is playing"))
             return None
 
         result = xmms.medialib_get_info(id)
@@ -720,7 +714,7 @@ class NowPlaying:
 
         # This can return error if the id is not in the medialib
         if result.iserror():
-            log.addwarning(_("ERROR: xmms2: medialib get info error: %(error)s") % {"error": result.get_error()})
+            log.add_warning(_("ERROR: xmms2: medialib get info error: %(error)s"), {"error": result.get_error()})
             return None
 
         # Extract entries from the dict
@@ -769,3 +763,6 @@ class NowPlaying:
             pass
 
         return True
+
+    def show(self):
+        self.now_playing_dialog.show()
