@@ -27,17 +27,18 @@ from gettext import gettext as _
 
 from gi.repository import Gdk
 from gi.repository import GLib
-from gi.repository import GObject as gobject
-from gi.repository import Gtk as gtk
+from gi.repository import GObject
+from gi.repository import Gtk
 
 from pynicotine import slskmessages
-from pynicotine.gtkgui.dialogs import EntryDialog
-from pynicotine.gtkgui.utils import HideColumns
-from pynicotine.gtkgui.utils import Humanize
-from pynicotine.gtkgui.utils import HumanSpeed
-from pynicotine.gtkgui.utils import InitialiseColumns
+from pynicotine.gtkgui.dialogs import entry_dialog
+from pynicotine.gtkgui.utils import hide_columns
+from pynicotine.gtkgui.utils import humanize
+from pynicotine.gtkgui.utils import human_speed
+from pynicotine.gtkgui.utils import initialise_columns
 from pynicotine.gtkgui.utils import PopupMenu
-from pynicotine.gtkgui.utils import showCountryTooltip
+from pynicotine.gtkgui.utils import show_country_tooltip
+from pynicotine.logfacility import log
 
 
 class UserList:
@@ -48,29 +49,29 @@ class UserList:
         self.frame = frame
         config = self.frame.np.config.sections
 
-        builder = gtk.Builder()
+        builder = Gtk.Builder()
 
         builder.set_translation_domain('nicotine')
         builder.add_from_file(os.path.join(os.path.dirname(os.path.realpath(__file__)), "ui", "buddylist.ui"))
 
-        self.TempWindow = builder.get_object("TempWindow")
+        self.temp_window = builder.get_object("TempWindow")
 
         for i in builder.get_objects():
             try:
-                self.__dict__[gtk.Buildable.get_name(i)] = i
+                self.__dict__[Gtk.Buildable.get_name(i)] = i
             except TypeError:
                 pass
 
-        self.TempWindow.remove(self.userlistvbox)
-        self.TempWindow.destroy()
+        self.temp_window.remove(self.userlistvbox)
+        self.temp_window.destroy()
 
         builder.connect_signals(self)
 
         """ Columns """
 
-        self.usersmodel = gtk.ListStore(
-            gobject.TYPE_OBJECT,  # (0)  status icon
-            gobject.TYPE_OBJECT,  # (1)  flag
+        self.usersmodel = Gtk.ListStore(
+            GObject.TYPE_OBJECT,  # (0)  status icon
+            GObject.TYPE_OBJECT,  # (1)  flag
             str,                  # (2)  username
             str,                  # (3)  hspeed
             str,                  # (4)  hfile count
@@ -79,31 +80,31 @@ class UserList:
             bool,                 # (7)  privileged
             str,                  # (8)  hlast seen
             str,                  # (9)  comments
-            gobject.TYPE_INT64,   # (10) status
-            gobject.TYPE_UINT64,  # (11) speed
-            gobject.TYPE_UINT64,  # (12) file count
+            GObject.TYPE_INT64,   # (10) status
+            GObject.TYPE_UINT64,  # (11) speed
+            GObject.TYPE_UINT64,  # (12) file count
             int,                  # (13) last seen
             str                   # (14) country
         )
 
         widths = self.frame.np.config.sections["columns"]["userlist_widths"]
-        self.cols = cols = InitialiseColumns(
-            self.UserList,
+        self.cols = cols = initialise_columns(
+            self.UserListTree,
             [_("Status"), widths[0], "pixbuf"],
             [_("Country"), widths[1], "pixbuf"],
-            [_("User"), widths[2], "text", self.CellDataFunc],
-            [_("Speed"), widths[3], "number", self.CellDataFunc],
-            [_("Files"), widths[4], "number", self.CellDataFunc],
+            [_("User"), widths[2], "text", self.cell_data_func],
+            [_("Speed"), widths[3], "number", self.cell_data_func],
+            [_("Files"), widths[4], "number", self.cell_data_func],
             [_("Trusted"), widths[5], "toggle"],
             [_("Notify"), widths[6], "toggle"],
             [_("Privileged"), widths[7], "toggle"],
-            [_("Last seen"), widths[8], "text", self.CellDataFunc],
-            [_("Comments"), widths[9], "edit", self.CellDataFunc]
+            [_("Last seen"), widths[8], "text", self.cell_data_func],
+            [_("Comments"), widths[9], "edit", self.cell_data_func]
         )
 
         self.col_status, self.col_country, self.col_user, self.col_speed, self.col_files, self.col_trusted, self.col_notify, self.col_privileged, self.col_last_seen, self.col_comments = cols
 
-        HideColumns(cols, config["columns"]["userlist"])
+        hide_columns(cols, config["columns"]["userlist"])
 
         self.col_status.set_sort_column_id(10)
         self.col_country.set_sort_column_id(14)
@@ -124,18 +125,18 @@ class UserList:
             config["columns"]["userlist"][1] = 0
 
         for render in self.col_trusted.get_cells():
-            render.connect('toggled', self.cell_toggle_callback, self.UserList, 5)
+            render.connect('toggled', self.cell_toggle_callback, self.UserListTree, 5)
 
         for render in self.col_notify.get_cells():
-            render.connect('toggled', self.cell_toggle_callback, self.UserList, 6)
+            render.connect('toggled', self.cell_toggle_callback, self.UserListTree, 6)
 
         for render in self.col_privileged.get_cells():
-            render.connect('toggled', self.cell_toggle_callback, self.UserList, 7)
+            render.connect('toggled', self.cell_toggle_callback, self.UserListTree, 7)
 
         for render in self.col_comments.get_cells():
-            render.connect('edited', self.cell_edited_callback, self.UserList, 9)
+            render.connect('edited', self.cell_edited_callback, self.UserListTree, 9)
 
-        self.UserList.set_model(self.usersmodel)
+        self.UserListTree.set_model(self.usersmodel)
 
         """ Buddy list """
 
@@ -149,8 +150,8 @@ class UserList:
                 time_from_epoch = 0
 
             row = [
-                self.frame.GetStatusImage(0),
-                self.frame.GetFlagImage(country),
+                self.frame.get_status_image(0),
+                self.frame.get_flag_image(country),
                 username,
                 "",
                 "",
@@ -168,68 +169,68 @@ class UserList:
 
             self.usersmodel.insert(0, row)
 
-        self.usersmodel.set_sort_column_id(2, gtk.SortType.ASCENDING)
+        self.usersmodel.set_sort_column_id(2, Gtk.SortType.ASCENDING)
 
         """ Popup """
 
-        self.Popup_Menu_PrivateRooms = PopupMenu(self.frame, False)
+        self.popup_menu_private_rooms = PopupMenu(self.frame, False)
         self.popup_menu = popup = PopupMenu(frame)
 
         popup.setup(
-            ("#" + _("Send _message"), popup.OnSendMessage),
+            ("#" + _("Send _message"), popup.on_send_message),
             ("", None),
-            ("#" + _("Show IP a_ddress"), popup.OnShowIPaddress),
-            ("#" + _("Get user i_nfo"), popup.OnGetUserInfo),
-            ("#" + _("Brow_se files"), popup.OnBrowseUser),
-            ("#" + _("Gi_ve privileges"), popup.OnGivePrivileges),
-            ("$" + _("_Ban this user"), popup.OnBanUser),
-            ("$" + _("_Ignore this user"), popup.OnIgnoreUser),
+            ("#" + _("Show IP a_ddress"), popup.on_show_ip_address),
+            ("#" + _("Get user i_nfo"), popup.on_get_user_info),
+            ("#" + _("Brow_se files"), popup.on_browse_user),
+            ("#" + _("Gi_ve privileges"), popup.on_give_privileges),
+            ("$" + _("_Ban this user"), popup.on_ban_user),
+            ("$" + _("_Ignore this user"), popup.on_ignore_user),
             ("", None),
-            ("$" + _("_Online notify"), self.OnNotify),
-            ("$" + _("_Privileged"), self.OnPrivileged),
-            ("$" + _("_Trusted"), self.OnTrusted),
+            ("$" + _("_Online notify"), self.on_notify),
+            ("$" + _("_Privileged"), self.on_privileged),
+            ("$" + _("_Trusted"), self.on_trusted),
             ("", None),
-            ("#" + _("Edit _comments"), self.OnEditComments),
-            ("#" + _("_Remove"), self.OnRemoveUser),
-            (1, _("Private rooms"), self.Popup_Menu_PrivateRooms, popup.OnPrivateRooms)
+            ("#" + _("Edit _comments"), self.on_edit_comments),
+            ("#" + _("_Remove"), self.on_remove_user),
+            (1, _("Private rooms"), self.popup_menu_private_rooms, popup.on_private_rooms, self.popup_menu_private_rooms)
         )
 
         items = self.popup_menu.get_children()
-        self.Menu_SendMessage = items[0]
-        self.Menu_ShowIPaddress = items[2]
-        self.Menu_GetUserInfo = items[3]
-        self.Menu_BrowseUser = items[4]
-        self.Menu_GivePrivileges = items[5]
-        self.Menu_BanUser = items[6]
-        self.Menu_IgnoreUser = items[7]
-        self.Menu_OnNotify = items[9]
-        self.Menu_OnPrivileged = items[10]
-        self.Menu_OnTrusted = items[11]
-        self.Menu_EditComments = items[13]
-        self.Menu_RemoveUser = items[14]
-        self.Menu_PrivateRooms = items[15]
+        self.menu_send_message = items[0]
+        self.menu_show_ip_address = items[2]
+        self.menu_get_user_info = items[3]
+        self.menu_browse_user = items[4]
+        self.menu_give_privileges = items[5]
+        self.menu_ban_user = items[6]
+        self.menu_ignore_user = items[7]
+        self.menu_on_notify = items[9]
+        self.menu_on_privileged = items[10]
+        self.menu_on_trusted = items[11]
+        self.menu_edit_comments = items[13]
+        self.menu_remove_user = items[14]
+        self.menu_private_rooms = items[15]
 
-        self.UserList.connect("button_press_event", self.OnPopupMenu)
+        self.UserListTree.connect("button_press_event", self.on_popup_menu)
 
-    def OnTooltip(self, widget, x, y, keyboard_mode, tooltip):
-        return showCountryTooltip(widget, x, y, tooltip, 14, 'flag_')
+    def on_tooltip(self, widget, x, y, keyboard_mode, tooltip):
+        return show_country_tooltip(widget, x, y, tooltip, 14, 'flag_')
 
-    def OnAddUser(self, widget):
+    def on_add_user(self, widget):
 
         text = self.AddUserEntry.get_text()
         if not text:
             return
 
         self.AddUserEntry.set_text("")
-        self.AddToList(text)
+        self.add_to_list(text)
 
-    def UpdateColours(self):
-        self.frame.SetTextBG(self.AddUserEntry)
+    def update_colours(self):
+        self.frame.set_text_bg(self.AddUserEntry)
 
-    def OnSettingsBanIgnore(self, widget):
-        self.frame.OnSettingsBanIgnore(widget)
+    def on_settings_ban_ignore(self, widget):
+        self.frame.on_settings_ban_ignore(widget)
 
-    def CellDataFunc(self, column, cellrenderer, model, iter, dummy="dummy"):
+    def cell_data_func(self, column, cellrenderer, model, iterator, dummy="dummy"):
 
         colour = self.frame.np.config.sections["ui"]["search"]
 
@@ -240,22 +241,22 @@ class UserList:
 
     def cell_toggle_callback(self, widget, index, treeview, pos):
 
-        iter = self.usersmodel.get_iter(index)
-        value = self.usersmodel.get_value(iter, pos)
+        iterator = self.usersmodel.get_iter(index)
+        value = self.usersmodel.get_value(iterator, pos)
 
-        self.usersmodel.set(iter, pos, not value)
+        self.usersmodel.set(iterator, pos, not value)
 
-        self.SaveUserList()
+        self.save_user_list()
 
     def cell_edited_callback(self, widget, index, value, treeview, pos):
 
         store = treeview.get_model()
-        iter = store.get_iter(index)
+        iterator = store.get_iter(index)
 
         if pos == 9:
-            self.SetComment(iter, store, value)
+            self.set_comment(iterator, store, value)
 
-    def SetLastSeen(self, user, online=False):
+    def set_last_seen(self, user, online=False):
 
         last_seen = ""
         time_from_epoch = 2147483647  # Gtk only allows range -2147483648 to 2147483647 in set()
@@ -271,27 +272,27 @@ class UserList:
                 break
 
         if not online:
-            self.SaveUserList()
+            self.save_user_list()
 
-    def SetComment(self, iter, store, comments=None):
+    def set_comment(self, iterator, store, comments=None):
 
-        user = store.get_value(iter, 2)
+        user = store.get_value(iterator, 2)
 
         if comments is not None:
 
             for i in self.usersmodel:
                 if i[2] == user:
-                    self.usersmodel.set(iter, 9, comments)
+                    self.usersmodel.set(iterator, 9, comments)
                     break
 
-            self.SaveUserList()
+            self.save_user_list()
 
-    def ConnClose(self):
+    def conn_close(self):
 
         for i in self.usersmodel:
             self.usersmodel.set(
                 i.iter,
-                0, self.frame.GetStatusImage(0),
+                0, self.frame.get_status_image(0),
                 3, "",
                 4, "",
                 10, 0,
@@ -301,46 +302,46 @@ class UserList:
 
             if self.usersmodel.get(i.iter, 8)[0] == "":
                 user = i[2]
-                self.SetLastSeen(user)
+                self.set_last_seen(user)
 
-    def OnPopupMenu(self, widget, event):
+    def on_popup_menu(self, widget, event):
 
-        d = self.UserList.get_path_at_pos(int(event.x), int(event.y))
+        d = self.UserListTree.get_path_at_pos(int(event.x), int(event.y))
 
         if d:
             path, column, x, y = d
-            model = self.UserList.get_model()
-            iter = model.get_iter(path)
-            user = model.get_value(iter, 2)
-            status = model.get_value(iter, 10)
+            model = self.UserListTree.get_model()
+            iterator = model.get_iter(path)
+            user = model.get_value(iterator, 2)
+            status = model.get_value(iterator, 10)
 
             if event.button != 3:
                 if event.type == Gdk.EventType._2BUTTON_PRESS:
-                    self.frame.privatechats.SendMessage(user, None, 1)
-                    self.frame.ChangeMainPage(None, "private")
+                    self.frame.privatechats.send_message(user, None, 1)
+                    self.frame.change_main_page(None, "private")
                 return
 
             self.popup_menu.set_user(user)
 
-            self.Menu_SendMessage.set_sensitive(status)
-            self.Menu_ShowIPaddress.set_sensitive(status)
-            self.Menu_GetUserInfo.set_sensitive(status)
-            self.Menu_BrowseUser.set_sensitive(status)
-            self.Menu_GivePrivileges.set_sensitive(status)
-            self.Menu_PrivateRooms.set_sensitive(
+            self.menu_send_message.set_sensitive(status)
+            self.menu_show_ip_address.set_sensitive(status)
+            self.menu_get_user_info.set_sensitive(status)
+            self.menu_browse_user.set_sensitive(status)
+            self.menu_give_privileges.set_sensitive(status)
+            self.menu_private_rooms.set_sensitive(
                 status or
                 self.popup_menu.user != self.frame.np.config.sections["server"]["login"]
             )
 
-            self.Menu_BanUser.set_active(user in self.frame.np.config.sections["server"]["banlist"])
-            self.Menu_IgnoreUser.set_active(user in self.frame.np.config.sections["server"]["ignorelist"])
-            self.Menu_OnNotify.set_active(model.get_value(iter, 6))
-            self.Menu_OnPrivileged.set_active(model.get_value(iter, 7))
-            self.Menu_OnTrusted.set_active(model.get_value(iter, 5))
+            self.menu_ban_user.set_active(user in self.frame.np.config.sections["server"]["banlist"])
+            self.menu_ignore_user.set_active(user in self.frame.np.config.sections["server"]["ignorelist"])
+            self.menu_on_notify.set_active(model.get_value(iterator, 6))
+            self.menu_on_privileged.set_active(model.get_value(iterator, 7))
+            self.menu_on_trusted.set_active(model.get_value(iterator, 5))
 
             self.popup_menu.popup(None, None, None, None, event.button, event.time)
 
-    def GetIter(self, user):
+    def get_iter(self, user):
 
         for i in self.usersmodel:
             if i[2] == user:
@@ -348,51 +349,51 @@ class UserList:
 
         return None
 
-    def GetUserStatus(self, msg):
+    def get_user_status(self, msg):
 
         user = msg.user
         status = msg.status
-        iter = self.GetIter(user)
+        iterator = self.get_iter(user)
 
-        if iter is None:
+        if iterator is None:
             return
 
-        if status == int(self.usersmodel.get_value(iter, 10)):
+        if status == int(self.usersmodel.get_value(iterator, 10)):
             return
 
-        notify = self.usersmodel.get_value(iter, 6)
+        notify = self.usersmodel.get_value(iterator, 6)
 
         if notify:
             status_text = [_("User %s is offline"), _("User %s is away"), _("User %s is online")][status]
-            self.frame.logMessage(status_text % user)
-            self.frame.Notifications.NewNotificationPopup(status_text % user)
+            log.add(status_text, user)
+            self.frame.notifications.new_notification(status_text % user)
 
-        img = self.frame.GetStatusImage(status)
+        img = self.frame.get_status_image(status)
         self.usersmodel.set(
-            iter,
+            iterator,
             0, img,
             10, status
         )
 
         if status:  # online
-            self.SetLastSeen(user, online=True)
-        elif self.usersmodel.get(iter, 8)[0] == "":  # disconnected
-            self.SetLastSeen(user)
+            self.set_last_seen(user, online=True)
+        elif self.usersmodel.get(iterator, 8)[0] == "":  # disconnected
+            self.set_last_seen(user)
 
-    def GetUserStats(self, msg):
+    def get_user_stats(self, msg):
 
         user = msg.user
-        iter = self.GetIter(user)
+        iterator = self.get_iter(user)
 
-        if iter is None:
+        if iterator is None:
             return
 
         country = msg.country
-        hspeed = HumanSpeed(msg.avgspeed)
-        hfiles = Humanize(msg.files)
+        hspeed = human_speed(msg.avgspeed)
+        hfiles = humanize(msg.files)
 
         self.usersmodel.set(
-            iter,
+            iterator,
             3, hspeed,
             4, hfiles,
             11, msg.avgspeed,
@@ -402,43 +403,43 @@ class UserList:
         if country is not None and country != "":
 
             country = "flag_" + country
-            self.SetUserFlag(user, country)
+            self.set_user_flag(user, country)
 
-    def SetUserFlag(self, user, country):
+    def set_user_flag(self, user, country):
 
-        iter = self.GetIter(user)
-        if iter is None:
+        iterator = self.get_iter(user)
+        if iterator is None:
             return
 
         if user not in [i[2] for i in self.usersmodel]:
             return
 
         self.usersmodel.set(
-            iter,
-            1, self.frame.GetFlagImage(country),
+            iterator,
+            1, self.frame.get_flag_image(country),
             14, country
         )
 
-    def AddToList(self, user):
+    def add_to_list(self, user):
 
         if user in [i[2] for i in self.usersmodel]:
             return
 
-        row = [self.frame.GetStatusImage(0), None, user, "", "", False, False, False, _("Never seen"), "", 0, 0, 0, 0, ""]
+        row = [self.frame.get_status_image(0), None, user, "", "", False, False, False, _("Never seen"), "", 0, 0, 0, 0, ""]
         self.usersmodel.append(row)
 
-        self.SaveUserList()
+        self.save_user_list()
         self.frame.np.queue.put(slskmessages.AddUser(user))
         self.frame.np.queue.put(slskmessages.GetPeerAddress(user))
 
-        for widget in self.frame.BuddiesComboEntries:
-            GLib.idle_add(widget.Append, user)
+        for widget in self.frame.buddies_combo_entries:
+            GLib.idle_add(widget.append, user)
 
         if self.frame.np.config.sections["words"]["buddies"]:
-            GLib.idle_add(self.frame.chatrooms.roomsctrl.UpdateCompletions)
-            GLib.idle_add(self.frame.privatechats.UpdateCompletions)
+            GLib.idle_add(self.frame.chatrooms.roomsctrl.update_completions)
+            GLib.idle_add(self.frame.privatechats.update_completions)
 
-    def OnEditComments(self, widget):
+    def on_edit_comments(self, widget):
 
         user = self.popup_menu.get_user()
 
@@ -449,7 +450,7 @@ class UserList:
         else:
             comments = ""
 
-        comments = EntryDialog(self.frame.MainWindow, _("Edit comments") + "...", _("Comments") + ":", comments)
+        comments = entry_dialog(self.frame.MainWindow, _("Edit comments") + "...", _("Comments") + ":", comments)
 
         if comments is not None:
             for i in self.usersmodel:
@@ -458,49 +459,51 @@ class UserList:
                     self.usersmodel.set(i.iter, 9, comments)
                     break
 
-            self.SaveUserList()
+            self.save_user_list()
 
-    def SaveUserList(self):
+    def save_user_list(self):
 
-        list = []
+        user_list = []
 
         for i in self.usersmodel:
             status_icon, flag, user, hspeed, hfile_count, trusted, notify, privileged, hlast_seen, comments, status, speed, file_count, last_seen, country = i
-            list.append([user, comments, notify, privileged, trusted, hlast_seen, country])
+            user_list.append([user, comments, notify, privileged, trusted, hlast_seen, country])
 
-        self.frame.np.config.sections["server"]["userlist"] = list
-        self.frame.np.config.writeConfiguration()
+        self.frame.np.config.sections["server"]["userlist"] = user_list
+        self.frame.np.config.write_configuration()
 
-    def saveColumns(self):
+    def save_columns(self):
 
         columns = []
         widths = []
-        for column in self.UserList.get_columns():
+
+        for column in self.UserListTree.get_columns():
             columns.append(column.get_visible())
             widths.append(column.get_width())
+
         self.frame.np.config.sections["columns"]["userlist"] = columns
         self.frame.np.config.sections["columns"]["userlist_widths"] = widths
 
-    def RemoveFromList(self, user):
+    def remove_from_list(self, user):
 
         for i in self.usersmodel:
             if i[2] == user:
                 self.usersmodel.remove(i.iter)
                 break
 
-        self.SaveUserList()
+        self.save_user_list()
 
-        for widget in self.frame.BuddiesComboEntries:
-            GLib.idle_add(widget.Remove, user)
+        for widget in self.frame.buddies_combo_entries:
+            GLib.idle_add(widget.remove, user)
 
         if self.frame.np.config.sections["words"]["buddies"]:
-            GLib.idle_add(self.frame.chatrooms.roomsctrl.UpdateCompletions)
-            GLib.idle_add(self.frame.privatechats.UpdateCompletions)
+            GLib.idle_add(self.frame.chatrooms.roomsctrl.update_completions)
+            GLib.idle_add(self.frame.privatechats.update_completions)
 
-    def OnRemoveUser(self, widget):
-        self.RemoveFromList(self.popup_menu.get_user())
+    def on_remove_user(self, widget):
+        self.remove_from_list(self.popup_menu.get_user())
 
-    def OnTrusted(self, widget):
+    def on_trusted(self, widget):
 
         user = self.popup_menu.get_user()
 
@@ -509,9 +512,9 @@ class UserList:
                 self.usersmodel.set(i.iter, 5, widget.get_active())
                 break
 
-        self.SaveUserList()
+        self.save_user_list()
 
-    def OnNotify(self, widget):
+    def on_notify(self, widget):
 
         user = self.popup_menu.get_user()
 
@@ -520,9 +523,9 @@ class UserList:
                 self.usersmodel.set(i.iter, 6, widget.get_active())
                 break
 
-        self.SaveUserList()
+        self.save_user_list()
 
-    def OnPrivileged(self, widget):
+    def on_privileged(self, widget):
 
         user = self.popup_menu.get_user()
 
@@ -531,4 +534,4 @@ class UserList:
                 self.usersmodel.set(i.iter, 7, widget.get_active())
                 break
 
-        self.SaveUserList()
+        self.save_user_list()
