@@ -27,8 +27,8 @@ from ast import literal_eval
 from gettext import gettext as _
 from time import time
 
+from pynicotine import slskmessages
 from pynicotine.logfacility import log
-from pynicotine.pynicotine import slskmessages
 
 
 returncode = {
@@ -40,12 +40,13 @@ returncode = {
 
 class PluginHandler(object):
 
-    def __init__(self, frame, plugindir):
+    def __init__(self, frame, plugindir, config):
         self.frame = frame
+        self.config = config
 
         log.add(_("Loading plugin handler"))
 
-        self.myUsername = self.frame.np.config.sections["server"]["login"]
+        self.my_username = self.config.sections["server"]["login"]
         self.plugindirs = []
         self.enabled_plugins = {}
         self.loaded_plugins = {}
@@ -63,10 +64,9 @@ class PluginHandler(object):
         self.plugindirs.append(plugindir)
 
         if os.path.isdir(plugindir):
-            # self.load_directory(self.plugindir)
             self.load_enabled()
         else:
-            log.add(_("It appears '%s' is not a directory, not loading plugins.") % plugindir)
+            log.add(_("It appears '%s' is not a directory, not loading plugins."), plugindir)
 
     def __findplugin(self, pluginname):
         for directory in self.plugindirs:
@@ -89,7 +89,7 @@ class PluginHandler(object):
         path = self.__findplugin(pluginname)
 
         if path is None:
-            log.add(_("Failed to load plugin '%s', could not find it.") % pluginname)
+            log.add(_("Failed to load plugin '%s', could not find it."), pluginname)
             return False
 
         sys.path.insert(0, path)
@@ -101,8 +101,6 @@ class PluginHandler(object):
         self.plugin_settings(instance)
         instance.LoadNotification()
 
-        # log.add("Loaded plugin %s (version %s) from %s" % (instance.__name__, instance.__version__, modulename))
-        # self.plugins.append((module, instance))
         sys.path = sys.path[1:]
 
         self.loaded_plugins[pluginname] = plugin
@@ -120,13 +118,12 @@ class PluginHandler(object):
 
             plugin.enable(self)
             self.enabled_plugins[pluginname] = plugin
-            log.add(_("Enabled plugin %s") % plugin.PLUGIN.__name__)
+            log.add(_("Enabled plugin %s"), plugin.PLUGIN.__name__)
 
         except Exception:
             from traceback import print_exc
             print_exc()
-            log.addwarning(_("Unable to enable plugin %s") % pluginname)
-            # common.log_exception(logger)
+            log.add(_("Unable to enable plugin %s"), pluginname)
             return False
 
         return True
@@ -156,8 +153,7 @@ class PluginHandler(object):
         except Exception:
             from traceback import print_exc
             print_exc()
-            log.addwarning(_("Unable to fully disable plugin %s") % pluginname)
-            # common.log_exception(logger)
+            log.add(_("Unable to fully disable plugin %s"), pluginname)
             return False
 
         return True
@@ -178,22 +174,22 @@ class PluginHandler(object):
             for line in f:
                 try:
                     key, val = line.split("=", 1)
-                    infodict[key] = literal_eval(val)
+                    infodict[key.strip()] = literal_eval(val.strip())
                 except ValueError:
                     pass  # this happens on blank lines
 
         return infodict
 
     def save_enabled(self):
-        self.frame.np.config.sections["plugins"]["enabled"] = list(self.enabled_plugins.keys())
+        self.config.sections["plugins"]["enabled"] = list(self.enabled_plugins.keys())
 
     def load_enabled(self):
-        enable = self.frame.np.config.sections["plugins"]["enable"]
+        enable = self.config.sections["plugins"]["enable"]
 
         if not enable:
             return
 
-        to_enable = self.frame.np.config.sections["plugins"]["enabled"]
+        to_enable = self.config.sections["plugins"]["enabled"]
 
         for plugin in to_enable:
             self.enable_plugin(plugin)
@@ -203,33 +199,32 @@ class PluginHandler(object):
             if not hasattr(plugin, "settings"):
                 return
 
-            if plugin.__id__ not in self.frame.np.config.sections["plugins"]:
-                self.frame.np.config.sections["plugins"][plugin.__id__] = plugin.settings
+            if plugin.__id__ not in self.config.sections["plugins"]:
+                self.config.sections["plugins"][plugin.__id__] = plugin.settings
 
             for i in plugin.settings:
-                if i not in self.frame.np.config.sections["plugins"][plugin.__id__]:
-                    self.frame.np.config.sections["plugins"][plugin.__id__][i] = plugin.settings[i]
+                if i not in self.config.sections["plugins"][plugin.__id__]:
+                    self.config.sections["plugins"][plugin.__id__][i] = plugin.settings[i]
 
-            customsettings = self.frame.np.config.sections["plugins"][plugin.__id__]
+            customsettings = self.config.sections["plugins"][plugin.__id__]
 
             for key in customsettings:
                 if key in plugin.settings:
                     plugin.settings[key] = customsettings[key]
 
                 else:
-                    log.add(_("Stored setting '%(name)s' is no longer present in the plugin") % {'name': key})
+                    log.add(_("Stored setting '%(name)s' is no longer present in the plugin"), {'name': key})
 
         except KeyError:
-            log.add("No custom settings found for %s" % (plugin.__name__,))
-            pass
+            log.add("No custom settings found for %s", (plugin.__name__,))
 
-    def TriggerPublicCommandEvent(self, room, command, args):
-        return self._TriggerCommand(command, room, args, public_command=True)
+    def trigger_public_command_event(self, room, command, args):
+        return self._trigger_command(command, room, args, public_command=True)
 
-    def TriggerPrivateCommandEvent(self, user, command, args):
-        return self._TriggerCommand(command, user, args, public_command=False)
+    def trigger_private_command_event(self, user, command, args):
+        return self._trigger_command(command, user, args, public_command=False)
 
-    def _TriggerCommand(self, command, source, args, public_command):
+    def _trigger_command(self, command, source, args, public_command):
         for module, plugin in self.enabled_plugins.items():
             try:
                 if plugin.PLUGIN is None:
@@ -246,14 +241,14 @@ class PluginHandler(object):
                     elif ret == returncode['pass']:
                         pass
                     else:
-                        log.add(_("Plugin %(module)s returned something weird, '%(value)s', ignoring") % {'module': module, 'value': str(ret)})
+                        log.add(_("Plugin %(module)s returned something weird, '%(value)s', ignoring"), {'module': module, 'value': str(ret)})
 
             except Exception:
                 from traceback import extract_stack
                 from traceback import extract_tb
                 from traceback import format_list
 
-                log.add(_("Plugin %(module)s failed with error %(errortype)s: %(error)s.\nTrace: %(trace)s\nProblem area:%(area)s") % {
+                log.add(_("Plugin %(module)s failed with error %(errortype)s: %(error)s.\nTrace: %(trace)s\nProblem area:%(area)s"), {
                     'module': module,
                     'errortype': sys.exc_info()[0],
                     'error': sys.exc_info()[1],
@@ -263,7 +258,7 @@ class PluginHandler(object):
 
         return False
 
-    def TriggerEvent(self, function, args):
+    def trigger_event(self, function, args):
         """Triggers an event for the plugins. Since events and notifications
         are precisely the same except for how n+ responds to them, both can be
         triggered by this function."""
@@ -274,7 +269,7 @@ class PluginHandler(object):
             try:
                 ret = getattr(plugin.PLUGIN, function)(*hotpotato)
 
-                if ret is not None and type(ret) is not tuple:
+                if ret is not None and not isinstance(ret, tuple):
                     if ret == returncode['zap']:
                         return None
                     elif ret == returncode['break']:
@@ -282,7 +277,7 @@ class PluginHandler(object):
                     elif ret == returncode['pass']:
                         pass
                     else:
-                        log.add(_("Plugin %(module)s returned something weird, '%(value)s', ignoring") % {'module': module, 'value': ret})
+                        log.add(_("Plugin %(module)s returned something weird, '%(value)s', ignoring"), {'module': module, 'value': ret})
 
                 if ret is not None:
                     hotpotato = ret
@@ -292,7 +287,7 @@ class PluginHandler(object):
                 from traceback import extract_tb
                 from traceback import format_list
 
-                log.add(_("Plugin %(module)s failed with error %(errortype)s: %(error)s.\nTrace: %(trace)s\nProblem area:%(area)s") % {
+                log.add(_("Plugin %(module)s failed with error %(errortype)s: %(error)s.\nTrace: %(trace)s\nProblem area:%(area)s"), {
                     'module': module,
                     'errortype': sys.exc_info()[0],
                     'error': sys.exc_info()[1],
@@ -302,82 +297,82 @@ class PluginHandler(object):
 
         return hotpotato
 
-    def SearchRequestNotification(self, searchterm, user, searchid):
-        self.TriggerEvent("SearchRequestNotification", (searchterm, user, searchid))
+    def search_request_notification(self, searchterm, user, searchid):
+        self.trigger_event("SearchRequestNotification", (searchterm, user, searchid))
 
-    def DistribSearchNotification(self, searchterm, user, searchid):
-        self.TriggerEvent("DistribSearchNotification", (searchterm, user, searchid))
+    def distrib_search_notification(self, searchterm, user, searchid):
+        self.trigger_event("DistribSearchNotification", (searchterm, user, searchid))
 
-    def PublicRoomMessageNotification(self, room, user, line):
-        self.TriggerEvent("PublicRoomMessageNotification", (room, user, line))
+    def public_room_message_notification(self, room, user, line):
+        self.trigger_event("PublicRoomMessageNotification", (room, user, line))
 
-    def IncomingPrivateChatEvent(self, user, line):
-        if user != self.myUsername:
+    def incoming_private_chat_event(self, user, line):
+        if user != self.my_username:
             # dont trigger the scripts on our own talking - we've got "Outgoing" for that
-            return self.TriggerEvent("IncomingPrivateChatEvent", (user, line))
+            return self.trigger_event("IncomingPrivateChatEvent", (user, line))
         else:
             return (user, line)
 
-    def IncomingPrivateChatNotification(self, user, line):
-        self.TriggerEvent("IncomingPrivateChatNotification", (user, line))
+    def incoming_private_chat_notification(self, user, line):
+        self.trigger_event("IncomingPrivateChatNotification", (user, line))
 
-    def IncomingPublicChatEvent(self, room, user, line):
-        return self.TriggerEvent("IncomingPublicChatEvent", (room, user, line))
+    def incoming_public_chat_event(self, room, user, line):
+        return self.trigger_event("IncomingPublicChatEvent", (room, user, line))
 
-    def IncomingPublicChatNotification(self, room, user, line):
-        self.TriggerEvent("IncomingPublicChatNotification", (room, user, line))
+    def incoming_public_chat_notification(self, room, user, line):
+        self.trigger_event("IncomingPublicChatNotification", (room, user, line))
 
-    def OutgoingPrivateChatEvent(self, user, line):
+    def outgoing_private_chat_event(self, user, line):
         if line is not None:
             # if line is None nobody actually said anything
-            return self.TriggerEvent("OutgoingPrivateChatEvent", (user, line))
+            return self.trigger_event("OutgoingPrivateChatEvent", (user, line))
         else:
             return (user, line)
 
-    def OutgoingPrivateChatNotification(self, user, line):
-        self.TriggerEvent("OutgoingPrivateChatNotification", (user, line))
+    def outgoing_private_chat_notification(self, user, line):
+        self.trigger_event("OutgoingPrivateChatNotification", (user, line))
 
-    def OutgoingPublicChatEvent(self, room, line):
-        return self.TriggerEvent("OutgoingPublicChatEvent", (room, line))
+    def outgoing_public_chat_event(self, room, line):
+        return self.trigger_event("OutgoingPublicChatEvent", (room, line))
 
-    def OutgoingPublicChatNotification(self, room, line):
-        self.TriggerEvent("OutgoingPublicChatNotification", (room, line))
+    def outgoing_public_chat_notification(self, room, line):
+        self.trigger_event("OutgoingPublicChatNotification", (room, line))
 
-    def OutgoingGlobalSearchEvent(self, text):
-        return self.TriggerEvent("OutgoingGlobalSearchEvent", (text,))
+    def outgoing_global_search_event(self, text):
+        return self.trigger_event("OutgoingGlobalSearchEvent", (text,))
 
-    def OutgoingRoomSearchEvent(self, rooms, text):
-        return self.TriggerEvent("OutgoingRoomSearchEvent", (rooms, text))
+    def outgoing_room_search_event(self, rooms, text):
+        return self.trigger_event("OutgoingRoomSearchEvent", (rooms, text))
 
-    def OutgoingBuddySearchEvent(self, text):
-        return self.TriggerEvent("OutgoingBuddySearchEvent", (text,))
+    def outgoing_buddy_search_event(self, text):
+        return self.trigger_event("OutgoingBuddySearchEvent", (text,))
 
-    def OutgoingUserSearchEvent(self, users):
-        return self.TriggerEvent("OutgoingUserSearchEvent", (users,))
+    def outgoing_user_search_event(self, users):
+        return self.trigger_event("OutgoingUserSearchEvent", (users,))
 
-    def UserResolveNotification(self, user, ip, port, country=None):
+    def user_resolve_notification(self, user, ip, port, country=None):
         """Notification for user IP:Port resolving.
 
         Note that country is only set when the user requested the resolving"""
-        self.TriggerEvent("UserResolveNotification", (user, ip, port, country))
+        self.trigger_event("UserResolveNotification", (user, ip, port, country))
 
-    def ServerConnectNotification(self):
-        self.TriggerEvent("ServerConnectNotification", (),)
+    def server_connect_notification(self):
+        self.trigger_event("ServerConnectNotification", (),)
 
-    def ServerDisconnectNotification(self, userchoice):
-        self.TriggerEvent("ServerDisconnectNotification", (userchoice, ))
+    def server_disconnect_notification(self, userchoice):
+        self.trigger_event("ServerDisconnectNotification", (userchoice, ))
 
-    def JoinChatroomNotification(self, room):
-        self.TriggerEvent("JoinChatroomNotification", (room,))
+    def join_chatroom_notification(self, room):
+        self.trigger_event("JoinChatroomNotification", (room,))
 
-    def LeaveChatroomNotification(self, room):
-        self.TriggerEvent("LeaveChatroomNotification", (room,))
+    def leave_chatroom_notification(self, room):
+        self.trigger_event("LeaveChatroomNotification", (room,))
 
-    def UploadQueuedNotification(self, user, virtualfile, realfile):
-        self.TriggerEvent("UploadQueuedNotification", (user, virtualfile, realfile))
+    def upload_queued_notification(self, user, virtualfile, realfile):
+        self.trigger_event("UploadQueuedNotification", (user, virtualfile, realfile))
 
-    def UserStatsNotification(self, user, stats):
-        self.TriggerEvent("UserStatsNotification", (user, stats))
+    def user_stats_notification(self, user, stats):
+        self.trigger_event("UserStatsNotification", (user, stats))
 
     """ Other Functions """
 
@@ -389,11 +384,11 @@ class PluginHandler(object):
 
     def sayprivate(self, user, text):
         '''Send user message in private (showing up in GUI)'''
-        self.frame.privatechats.users[user].SendMessage(text)
+        self.frame.privatechats.users[user].send_message(text)
 
     def sendprivate(self, user, text):
         '''Send user message in private (not showing up in GUI)'''
-        self.frame.privatechats.SendMessage(user, text)
+        self.frame.privatechats.send_message(user, text)
 
 
 class ResponseThrottle(object):
@@ -440,7 +435,7 @@ class ResponseThrottle(object):
         if nick in self.frame.np.config.sections["server"]["ignorelist"]:
             willing_to_respond, reason = False, "The nick is ignored"
 
-        elif self.frame.UserIpIsIgnored(nick):
+        elif self.frame.user_ip_is_ignored(nick):
             willing_to_respond, reason = False, "The nick's Ip is ignored"
 
         elif not port:
@@ -471,7 +466,7 @@ class ResponseThrottle(object):
         if self.logging:
             if not willing_to_respond:
                 base_log_msg = "{} plugin request rejected - room '{}', nick '{}'".format(self.plugin_name, room, nick)
-                log.adddebug("{} - {}".format(base_log_msg, reason))
+                log.add_debug("{} - {}".format(base_log_msg, reason))
 
         return willing_to_respond
 
@@ -485,7 +480,6 @@ class BasePlugin(object):
 
     __name__ = "BasePlugin"
     __desc__ = "No description provided"
-    # __id__ = "baseplugin_original" # you normally don't have to set this manually
     __version__ = "2016-08-30"
     __publiccommands__ = []
     __privatecommands__ = []
@@ -509,76 +503,76 @@ class BasePlugin(object):
     def init(self):
         pass
 
-    def LoadSettings(self, settings):
+    def LoadSettings(self, settings):  # noqa
         self.settings = settings
 
-    def LoadNotification(self):
+    def LoadNotification(self):  # noqa
         pass
 
-    def PublicRoomMessageNotification(self, room, user, line):
+    def PublicRoomMessageNotification(self, room, user, line):  # noqa
         pass
 
-    def SearchRequestNotification(self, searchterm, user, searchid):
+    def SearchRequestNotification(self, searchterm, user, searchid):  # noqa
         pass
 
-    def DistribSearchNotification(self, searchterm, user, searchid):
+    def DistribSearchNotification(self, searchterm, user, searchid):  # noqa
         pass
 
-    def IncomingPrivateChatEvent(self, user, line):
+    def IncomingPrivateChatEvent(self, user, line):  # noqa
         pass
 
-    def IncomingPrivateChatNotification(self, user, line):
+    def IncomingPrivateChatNotification(self, user, line):  # noqa
         pass
 
-    def IncomingPublicChatEvent(self, room, user, line):
+    def IncomingPublicChatEvent(self, room, user, line):  # noqa
         pass
 
-    def IncomingPublicChatNotification(self, room, user, line):
+    def IncomingPublicChatNotification(self, room, user, line):  # noqa
         pass
 
-    def OutgoingPrivateChatEvent(self, user, line):
+    def OutgoingPrivateChatEvent(self, user, line):  # noqa
         pass
 
-    def OutgoingPrivateChatNotification(self, user, line):
+    def OutgoingPrivateChatNotification(self, user, line):  # noqa
         pass
 
-    def OutgoingPublicChatEvent(self, room, line):
+    def OutgoingPublicChatEvent(self, room, line):  # noqa
         pass
 
-    def OutgoingPublicChatNotification(self, room, line):
+    def OutgoingPublicChatNotification(self, room, line):  # noqa
         pass
 
-    def OutgoingGlobalSearchEvent(self, text):
+    def OutgoingGlobalSearchEvent(self, text):  # noqa
         pass
 
-    def OutgoingRoomSearchEvent(self, rooms, text):
+    def OutgoingRoomSearchEvent(self, rooms, text):  # noqa
         pass
 
-    def OutgoingBuddySearchEvent(self, text):
+    def OutgoingBuddySearchEvent(self, text):  # noqa
         pass
 
-    def OutgoingUserSearchEvent(self, users):
+    def OutgoingUserSearchEvent(self, users):  # noqa
         pass
 
-    def UserResolveNotification(self, user, ip, port, country):
+    def UserResolveNotification(self, user, ip, port, country):  # noqa
         pass
 
-    def ServerConnectNotification(self):
+    def ServerConnectNotification(self):  # noqa
         pass
 
-    def ServerDisconnectNotification(self, userchoice):
+    def ServerDisconnectNotification(self, userchoice):  # noqa
         pass
 
-    def JoinChatroomNotification(self, room):
+    def JoinChatroomNotification(self, room):  # noqa
         pass
 
-    def LeaveChatroomNotification(self, room):
+    def LeaveChatroomNotification(self, room):  # noqa
         pass
 
-    def UploadQueuedNotification(self, user, virtualfile, realfile):
+    def UploadQueuedNotification(self, user, virtualfile, realfile):  # noqa
         pass
 
-    def UserStatsNotification(self, user, stats):
+    def UserStatsNotification(self, user, stats):  # noqa
         pass
 
     # The following are functions to make your life easier,
@@ -605,17 +599,17 @@ class BasePlugin(object):
 
         msg = slskmessages.SayChatroom(room, text)
         msg.user = user
-        room.SayChatRoom(msg, text)
+        room.say_chat_room(msg, text)
         return True
 
     # The following are functions used by the plugin system,
     # you are not allowed to override these.
-    def PublicCommandEvent(self, command, room, args):
+    def PublicCommandEvent(self, command, room, args):  # noqa
         for (trigger, func) in self.__publiccommands__:
             if trigger == command:
                 return func(self, room, args)
 
-    def PrivateCommandEvent(self, command, user, args):
+    def PrivateCommandEvent(self, command, user, args):  # noqa
         for (trigger, func) in self.__privatecommands__:
             if trigger == command:
                 return func(self, user, args)
